@@ -23,5 +23,7 @@
 #include "rb-pango.h"
 
 G_GNUC_INTERNAL void rbpango_attribute_init(VALUE mPango);
+G_GNUC_INTERNAL void rbpango_attr_iterator_init(VALUE mPango);
 G_GNUC_INTERNAL void rbpango_attr_list_init(VALUE mPango);
 G_GNUC_INTERNAL void rbpango_context_init(VALUE mPango);
+G_GNUC_INTERNAL void rbpango_scale_init(VALUE mPango);
